#!/bin/sh
#
# Post deinstall script for IMNSearch indexes
#       1) Deegisters the index with the search engine if possible
#       2) Delete the entry for the index from the lookup table
#
# script debug flag
# set -x
##############################################################################
#        INDEX specific section
##############################################################################
#
# Put in index type (SBCS/DBCS)
# NOTE: NO MIXTURE OF INDEX TYPES
# all indexes that get installed in one installation option have
# to have the same type, either SBCS or DBCS
#
index_type=SBCS
#
#
# Put in names of index directories being used during installation
# e.g if your index installed in /usr/docsearch/AIX4cmds/data etc
# use AIXcmds as you indexdir_name_1
# ATTENTION: the name is use case sensitive
# The index name is being generated from the directory name by
# uppercasing
indexdir_name_1="$1"
#
##############################################################################
#        End of INDEX specfic section
##############################################################################
#
##############################################################################
#
# !!! DON'T CHANGE ANYTHING FROM HERE DOWN !!!
##############################################################################
dummy()
{
return
}
system=`uname`
case "$system" in
        "AIX")  ECHO=echo
                netq_install_dir="/usr/IMNSearch"
                ;;
        "HP-UX")ECHO=dummy
                netq_install_dir="/opt/IMNSearch"
                if [ "$LANG" = "" ]
                then
                  LANG=C
                  export LANG
                fi
                NLSPATH="$NLSPATH:/usr/lib/nls/%L/%N:/usr/lib/nls/msg/%L/%N"
                export NLSPATH
                ;;
        "SunOS")ECHO=dummy
                netq_install_dir="/opt/IMNSearch"
                if [ "$LANG" = "" ]
                then
                    LANG=C
                    export LANG
                fi
                NLSPATH="$NLSPATH:/usr/lib/locale/%L/LC_MESSAGES/%N"
                export NLSPATH
                ;;
        *)      echo "Operating system not supported."
                exit 1
                ;;
esac
umask 022
# directory where indexes are search by the engine
src_index_dir="/usr/docsearch/indexes"
# directory for writeable file of the index
trg_index_dir="/var/docsearch/indexes"
# lookup table file for all indexes
map_file="imnmap.dat"
#
# define system specific commands with full path
sys_ls="/usr/bin/ls"
sys_cp="/usr/bin/cp"
sys_rm="/usr/bin/rm"
sys_mkdir="/usr/bin/mkdir"
sys_chmod="/usr/bin/chmod"
sys_chown="/usr/bin/chown"
sys_grep="/usr/bin/grep"

# command to delete index
del_idx_sbcs="$netq_install_dir/cli/imnixdel"
del_idx_dbcs="$netq_install_dir/cli/imqixdel"
#
# dependend on the index type, switch commands an environment
if [ $index_type = "SBCS" ]
then
  del_idx_cmd=$del_idx_sbcs
  instance_name=imnhelp
  start_exe=/usr/bin/imnss
else
  if [ $index_type = "DBCS" ]
  then
    # set the correct environment
    if [ -x $netq_install_dir/bin/imq_env ]
    then
      . $netq_install_dir/bin/imq_env
    fi
    del_idx_cmd=$del_idx_dbcs
    instance_name=dbcshelp
    start_exe=/usr/bin/imqss
  else
    $ECHO "Either none or a wrong index_type has been specified ..."
    exit 1
  fi
fi


# Deregister the index with the search engine
#       Will do nothing if IMNSearch is not installed
#
if [  -x $start_exe ]
then
        # Start the Search engine
        $start_exe -start $instance_name
fi

if [ -f $src_index_dir/$map_file ]
then
   if [ -f $src_index_dir/$map_file.save ]
   then
     # this is a cleanup of a failed installation
     $sys_cp $src_index_dir/$map_file.save $src_index_dir/$map_file
     $sys_rm -f $src_index_dir/$map_file.save
     if [ -d $trg_index_dir ]
     then
       $sys_cp $src_index_dir/$map_file $trg_index_dir/$map_file
     fi
     exit 0
   fi

   # save the config file before doing any work
   $sys_cp $src_index_dir/$map_file $src_index_dir/$map_file.save
   if [ $? -ne 0 ]
   then
       $sys_rm -f $src_index_dir/$map_file.save
       $ECHO "Could not create $src_index_dir/$map_file.save !"
       $ECHO "Exiting...."
       exit 1
   fi
fi

# arrays start with offset 1     DO NOT CHANGE
count=1

while [ ! -z "`eval echo \\$indexdir_name_$count`" ]
do
  indexdir_name="`eval echo \\$indexdir_name_$count`"
  indexname=`echo $indexdir_name | tr "[:lower:]" "[:upper:]"`
  if [  -x $start_exe ]
  then
        # Deregister the index with the search engine
        $del_idx_cmd $indexname

        # delete all created directories
        $sys_rm -rf $trg_index_dir/$indexdir_name
  fi
  # remove directory structure if still existing
  if [ -d $src_index_dir/$indexdir_name ]
  then
    $sys_rm -rf $src_index_dir/$indexdir_name
  fi

  #delete the entry in the lookup table for the index
  if [ -f $src_index_dir/$map_file ]
  then
     # save the config file before doing any grep
     $sys_cp $src_index_dir/$map_file $src_index_dir/$map_file.grep
     if [ $? -ne 0 ]
     then
         $sys_rm -f $src_index_dir/$map_file.grep
         $ECHO "Could not create $src_index_dir/$map_file.save !"
         $ECHO "Exiting...."
         exit 1
     fi
     # remove the existing map file, it will be recreated with the grep command
     $sys_rm -f $src_index_dir/$map_file
     if [ $? -ne 0 ]
     then
         $sys_rm -f $src_index_dir/$map_file.grep
         $ECHO "Could not remove file $src_index_dir/$map_file !"
         $ECHO "Exiting...."
         exit 1
     fi
     # remove the entry for the index
     $sys_grep -v '^"'$indexname'"' $src_index_dir/$map_file.grep > $src_index_dir/$map_file 2> /dev/null

     if [ $? -gt 1 ] # return code will be checked, 1 indicates that no lines are left
     then
        $sys_cp $src_index_dir/$map_file.save $src_index_dir/$map_file
        $ECHO "Error removing entry from mapping table file $src_index_dir/$map_file !"
        $ECHO "Kept old file. Exiting ...."
        exit 1
     fi

     # remove grep file
     $sys_rm -f $src_index_dir/$map_file.grep

     # if it was the last entry, remove the empty files
     if [ ! -s $src_index_dir/$map_file ]
     then
         $sys_rm -f $src_index_dir/$map_file
         $sys_rm -f $src_index_dir/$map_file.save
         if [ -f $trg_index_dir/$map_file ]
         then
           $sys_rm -f $trg_index_dir/$map_file
         fi
         exit 0
     fi
  fi
  count=`expr ${count} + 1`
done

if [ -d $trg_index_dir ]
then
  $sys_cp $src_index_dir/$map_file $trg_index_dir/$map_file
  if [ $? -ne 0 ]
  then
      $ECHO "Could not copy to $trg_index_dir/$map_file !"
      $ECHO "Exiting...."
      $sys_rm -f $trg_index_dir/$map_file
      $sys_cp $src_index_dir/$map_file.save $trg_index_dir/$map_file
      $sys_cp $src_index_dir/$map_file.save $src_index_dir/$map_file
      exit 1
  fi
fi

#Every thing is ok, now delete save file

if [ -f $src_index_dir/$map_file.save ]
then
  $sys_rm -f $src_index_dir/$map_file.save
fi

if [ -f $src_index_dir/$map_file.grep ]
then
  $sys_rm -f $src_index_dir/$map_file.grep
fi

exit 0
